@@ -4,7 +4,7 @@ use warnings;
 
 # ABSTRACT: Simple Diffing of DBIC Schemas
 
-our $VERSION = '1.07';
+our $VERSION = '1.10';
 
 use Moo;
 with 'DBIx::Class::Schema::Diff::Role::Common';
@@ -13,7 +13,7 @@ use Types::Standard qw(:all);
 use Module::Runtime;
 use Try::Tiny;
 use List::Util;
-use Hash::Layout;
+use Hash::Layout 2.00;
 use Array::Diff;
 
 use DBIx::Class::Schema::Diff::Schema;
@@ -101,6 +101,16 @@ sub filter_out {
 sub _coerce_filter_args {
   my ($self,@args) = @_;
   
+  # This is the cleanest solution for wildcards to match as expected, not requiring the
+  # user to append a trailing '*' since they don't have to when doing an exact match
+  @args = map {
+    my ($one,$two) = ($_ && ! ref($_)) ? split (/\:/,$_,2) : ();
+    (
+      $one && $two && $one ne '*' && ($one =~ /\*/)
+      && ($two eq 'columns' || $two eq 'relationships' || $two eq 'constraints')
+    ) ? $_.'*' : $_
+  } @args;
+  
   my $params = (
     scalar(@args) > 1
     || ! ref($args[0])
@@ -519,9 +529,8 @@ to some of these concepts.
 
 =item *
 
-Filter string arguments are I<NOT> glob patterns, so you can't do things like C<'Arti*'> to match
-sub-strings (this may be a worthwhile feature to add in a later version). The wildcard C<*> applies
-to whole items only.
+As of version 1.1 filter string arguments I<are> glob patterns, so you can also do things like 
+C<'Arti*'> to match sub-strings. See the unit tests for examples.
 
 =item *
 
